import 'dart:async';
import 'dart:io';

import 'package:flutter/services.dart';

/// Flutter plugin for iOS DeviceCheck.
///
/// See https://developer.apple.com/documentation/devicecheck
class IosDeviceCheck {
  static const MethodChannel _channel = const MethodChannel('ios_device_check');

  static bool _ensureSupportedPlatform() {
    if (Platform.isIOS)
      return true;
    throw("ios_device_check plugin is only available on iOS.");
  }

  /// Boolean value derived from DCDevice's `isSupported` property.
  static Future<bool> get isSupported async =>
      _ensureSupportedPlatform() && await _channel.invokeMethod('isSupported');

  /// The token string derived from DCDevice's `generateToken` method.
  static Future<String> generateToken() async {
    _ensureSupportedPlatform();
    return await _channel.invokeMethod('generateToken');
  }
}